import payloadConfig from "@/payload.config";
import { CardPropertyData } from "@/schema/property";
import { FetchPropertyParams } from "@/schema/services/property";
import { formatDate } from "@/utils/datetime";
import { getPayload, Where } from "payload";

export async function fetchProperty({
  page,
  name = "",
  location,
  min_price,
  max_price,
  min_area,
  max_area,
}: FetchPropertyParams = {}) {
  const payload = await getPayload({ config: payloadConfig });

  const queryCondition: Where = {
    _status: { equals: "published" },
  };

  if (!!name) {
    queryCondition["name"] = {
      contains: name,
    };
  }
  if (!!min_price) {
    queryCondition["base_price"] = {
      greater_than_equal: min_price,
    };
  }
  if (!!max_price) {
    queryCondition["base_price"] = {
      less_than_equal: max_price,
    };
  }
  if (!!min_area) {
    queryCondition["aboutGroup.area"] = {
      greater_than_equal: min_area,
    };
  }
  if (!!max_area) {
    queryCondition["aboutGroup.area"] = {
      less_than_equal: max_area,
    };
  }
  if (!!location) {
    queryCondition["addressGroup.state_code"] = {
      equals: location,
    };
  }

  const dataQuery = await payload.find({
    collection: "properties",
    page,
    pagination: true,
    limit: 10,
    where: queryCondition,
  });

  const formattedData: CardPropertyData[] = dataQuery.docs.map((item) => {
    return {
      slug: "",
      title: item.name,
      price: item.base_price,
      area: item.aboutGroup.area,
      propertyType: item.propertyType,
      bathrooms_count: item.aboutGroup.bathrooms_count,
      bedrooms_count: item.aboutGroup.bedrooms_count,
      images: item.images.map((img) =>
        typeof img !== "number" ? { url: img?.url ?? "", alt: img.alt } : { url: "", alt: "" }
      ),
      posted_at: formatDate(item.createdAt),
    };
  });

  return {
    ...dataQuery,
    formattedData,
  };
}
